'use strict'
var __importDefault =
	(this && this.__importDefault) ||
	function (mod) {
		return mod && mod.__esModule ? mod : { default: mod }
	}
Object.defineProperty(exports, '__esModule', { value: true })
const process_1 = require('process')
const normalify_1 = __importDefault(require('normalify'))
/**
 * Get the value of a CLI argument that is provided via:
 * --arg
 * --arg=value
 * --no-arg
 * --no-arg=value
 * @param name the name of the argument to find
 * @param args the list of the arguments to search, defaults to `process.argv`
 * @returns the result typecasted to whatever format the value represented
 */
function default_1(name, args = process_1.argv) {
	for (const arg of args) {
		let value,
			invert = false
		// match arg
		if (arg.startsWith('--' + name)) {
			value = arg.substring(name.length + 2)
		} else if (arg.startsWith('--no-' + name)) {
			value = arg.substring(name.length + 5)
			invert = true
		} else {
			// not found in this argument, continue to next argument
			continue
		}
		// adapt the value
		if (value === '') {
			value = true
		} else if (value[0] === '=') {
			value = value.substring(1)
			if (value === '') {
				value = false
			} else {
				value = normalify_1.default(value)
			}
		}
		// return the value, and invert it if necessary
		return invert ? !value : value
	}
}
exports.default = default_1
